/*
 * Purpose: AddressManager frame
 * Author:  Frank Bu
 * Created: 2002
 */

#ifndef ADDRESS_MANAGER_FRAME_H
#define ADDRESS_MANAGER_FRAME_H

#include "AddressManager.h"
#include "AddressGridTable.h"

/**
 * The frame with the wxGrid.
 */
class AddressManagerFrame: public wxFrame
{
public:
	/**
	 * Creates a frame, sets the accelerators and shows a default table.
	 */
    AddressManagerFrame(wxFrame *frame, const wxString& title, const wxPoint& pos, const wxSize& size);

	/**
	 * Deletes the table.
	 */
    ~AddressManagerFrame();

	/**
	 * Callback for the about menu command.
	 */
	void OnAbout(wxCommandEvent& event);

	/**
	 * Callback for the file new menu command.
	 */
	void OnMenuFileNew(wxCommandEvent& event);

	/**
	 * Callback for the file open menu command.
	 */
	void OnMenuFileOpen(wxCommandEvent& event);

	/**
	 * Callback for the file close menu command (currently deactivated).
	 */
	void OnMenuFileClose(wxCommandEvent& event);

	/**
	 * Saves the table, if the current filename is set. If the
	 * filename is not set, FileSaveAsImpl will be called.
	 * \return false, if the user has canceled the dialog, if FileSaveAsImpl
	 *		   was called, otherwise true, if no error occured.
	 */
	bool FileSaveImpl();

	/**
	 * Callback for the file save menu command.
	 */
	void OnMenuFileSave(wxCommandEvent& event);

	/**
	 * Shows the save dialog and saves the table, if the dialog
	 * was commited.
	 * \return true, if the user has not canceled the dialog.
	 */
	bool FileSaveAsImpl();

	/**
	 * Callback for the file save as menu command.
	 */
	void OnMenuFileSaveAs(wxCommandEvent& event);

	/**
	 * Callback for the file exit menu command.
	 */
	void OnMenuFileExit(wxCommandEvent& event);

	/**
	 * Callback for the edit cut menu command.
	 */
	void OnMenuEditCut(wxCommandEvent& event);

	/**
	 * Callback for the edit copy menu command.
	 */
	void OnMenuEditCopy(wxCommandEvent& event);

	/**
	 * Callback for the edit paste menu command.
	 */
	void OnMenuEditPaste(wxCommandEvent& event);

	/**
	 * Callback for the edit find menu command.
	 */
	void OnMenuEditFind(wxCommandEvent& event);

	/**
	 * Callback for the table doublet menu command.
	 */
	void OnMenuTableDoublet(wxCommandEvent& event);

	/**
	 * Callback for the table sort menu command.
	 */
	void OnMenuTableSort(wxCommandEvent& event);

	/**
	 * Callback for the table config menu command.
	 */
	void OnMenuTableConfig(wxCommandEvent& event);

	/**
	 * Callback for the export email menu command (currently deactivated).
	 */
	void OnMenuExportEmail(wxCommandEvent& event);

	/**
	 * Callback for the export SMS menu command (currently deactivated).
	 */
	void OnMenuExportSMS(wxCommandEvent& event);

	/**
	 * Callback for the export fax menu command (currently deactivated).
	 */
	void OnMenuExportFax(wxCommandEvent& event);

	/**
	 * Callback for the activate event.
	 */
    void OnActivate(wxActivateEvent& event);

	/**
	 * Callback for the size event.
	 */
    void OnSize(wxSizeEvent &event);

	/**
	 * Is called from every method which wants to close the frame
	 * and exit the application. Checks the dirty flag and calls
	 * the FileSaveImpl, if something is to save and returns the result.
	 * \param true, if the application can be exited, false, if
	 *        the user vetoed it.
	 */
	bool onExit();

	/**
	 * Callback for the close event.
	 */
	void OnClose(wxCloseEvent& event);

	/**
	 * Sets the dirty flag to true.
	 */
	void setDirty();

DECLARE_EVENT_TABLE()

private:
	void copy(bool erase);
	wxGrid* m_pGrid;
	AddressGridTable* m_pTable;
	wxString m_currentFilename;
	wxString m_lastSearchString;
	bool m_dirty;
};

#endif
