/*
 * Purpose: All modal dialogs for AddressManager
 * Author:  Frank Bu
 * Created: 2002
 */

#ifndef ADDRESS_MANAGER_DIALOGS_H
#define ADDRESS_MANAGER_DIALOGS_H


#include <wx/wx.h>

#include "AddressManager.h"

/**
 * Dialog for adding, renaming, moving and removing columns.
 */
class ColumnDialog : public wxDialog
{
public:
	/**
	 * Creates a new column config dialog with the current columns.
	 * \param parent The frame.
	 * \param columns The columns of the current table.
	 */
    ColumnDialog(wxWindow* parent, ColumnFieldArray& columns);

	/**
	 * Deletes all new created columns.
	 */
    ~ColumnDialog();

    // event handlers
    void OnListBox(wxCommandEvent &event);
	void OnNewButton(wxCommandEvent &event);
	void OnRenameButton(wxCommandEvent &event);
	void OnUpButton(wxCommandEvent &event);
	void OnRemoveButton(wxCommandEvent &event);
	void OnDownButton(wxCommandEvent &event);

	/**
	 * Gets an array with the configured columns.
	 * The columns are perhaps sorted in a way the
	 * user wants, perhaps labels are changed and
	 * if columns added, the isNew method of this
	 * columns returns true.
	 */
	ColumnFieldArray getNewColumns();

private:
    // any class wishing to process wxWindows events must use this macro
    DECLARE_EVENT_TABLE()

    wxListBox*  m_listBox;
	wxTextCtrl* m_newColumnTextCtrl;
	wxTextCtrl* m_editColumnTextCtrl;
	wxButton* m_editButton;

	ColumnFieldArray m_columns;
};

/**
 * Dialog for choosing the columns for sorting the table.
 */
class SortDialog : public wxDialog
{
public:
	/**
	 * Creates a new sort dialog with the current columns.
	 * \param parent The frame.
	 * \param columns The columns of the current table.
	 */
    SortDialog(wxWindow* parent, ColumnFieldArray& columns);

	/**
	 * Gets the columns in the order the user has choosen for
	 * sorting the table.
	 * \return ColumnFieldArray, use getOldIndex for retrieving
	 *         the column index (-1 if disabled).
	 */
	ColumnFieldArray getSortOrder();

	/**
	 * Closes the dialog and retrieves the sort order.
	 */
	void OnOK(wxCommandEvent& event);

private:
	DECLARE_EVENT_TABLE()

	wxChoice* m_sort1Choice;
	wxChoice* m_sort2Choice;
	wxChoice* m_sort3Choice;
	wxRadioButton* m_sort1CheckboxUp;
	wxRadioButton* m_sort1CheckboxDown;
	wxRadioButton* m_sort2CheckboxUp;
	wxRadioButton* m_sort2CheckboxDown;
	wxRadioButton* m_sort3CheckboxUp;
	wxRadioButton* m_sort3CheckboxDown;

	ColumnFieldArray m_columns;
};



/**
 * Dialog for showing the about box.
 */
class AddressManagerAboutDialog : public wxDialog
{
public:
    AddressManagerAboutDialog(wxWindow *parent);
};


#endif  // ADDRESS_MANAGER_DIALOGS
